@@ -13,7 +13,7 @@ no warnings qw( threads recursion uninitialized once redefine );
 
 package MCE::Hobo;
 
-our $VERSION = '1.888';
+our $VERSION = '1.889';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -120,7 +120,7 @@ sub init {
       # silently clobbers Perl's srand function, and does not seed Perl's
       # pseudo-random generator. https://perlmonks.org/?node_id=11159773
 
-      if ( $INC{'PDL/Primitive.pm'} && PDL::Primitive->can('srand') ) {
+      if ( $INC{'PDL/Primitive.pm'} ) {
          # Call PDL's random() function if exported i.e. use PDL.
 
          my $caller = caller(); local $@;
@@ -1008,7 +1008,7 @@ MCE::Hobo - A threads-like parallelization module
 
 =head1 VERSION
 
-This document describes MCE::Hobo version 1.888
+This document describes MCE::Hobo version 1.889
 
 =head1 SYNOPSIS
 
